==> ejc-labor-api-3.0.0-20221125.123612-85-sources.jar: com/ejianc/business/labor/vo/SalarySlipVO.java <==
package com.ejianc.business.labor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 工资条
 * 
 * @author generator
 * 
 */
public class SalarySlipVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编码
    private Long salaryId; // 工人工资单主表id
    private Long salaryDetailId; // 工人工资单子表id
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date salaryMonth; // 工资月份
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Long workerId; // 工人id
    private String workerName; // 工人
    private Long contractId; // 合同id
    private String contractName; // 合同名称
    private Long supplierId; // 加班计量方式
    private String supplierName; // 加班工作量
    private String idCard; // 身份证号码
    private String teamId; // 班组id
    private String teamName; // 班组名称
    private String workType; // 工种id
    private String workTypeName; // 工种名称
    private Integer sex; // 性別 1:男 2:女
    private String phone; // 手机号
    private String bankCard; // 银行卡号
    private String bankName; // 开户行
    private Integer wagesType; // 工资类型
    private Integer sysCheckNum; // 系统考勤天数
    private BigDecimal price; // 单价
    private BigDecimal actualCheckNum; // 实际考勤
    private BigDecimal mny; // 金额
    private BigDecimal overtimeMny; // 加班费
    private BigDecimal deductMny; // 扣款费用
    private String deductReason; // 扣款原因
    private BigDecimal shouldSalaryMny; // 应发工资:工作量*单价+加班工作量*单价
    private String memo; // 备注
    private Integer source; // 来源 1：花名册 2：自制
    private Integer ackFlag; // 确认状态：1：已确认:0：未确认
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private  Date  ackTime; // 确认时间
    private String ackEquipment; // 确认设备信息

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getSalaryId() {
        return salaryId;
    }

    public void setSalaryId(Long salaryId) {
        this.salaryId = salaryId;
    }
    public Long getSalaryDetailId() {
        return salaryDetailId;
    }

    public void setSalaryDetailId(Long salaryDetailId) {
        this.salaryDetailId = salaryDetailId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getWorkerId() {
        return workerId;
    }

    public void setWorkerId(Long workerId) {
        this.workerId = workerId;
    }
    public String getWorkerName() {
        return workerName;
    }

    public void setWorkerName(String workerName) {
        this.workerName = workerName;
    }

    public Date getSalaryMonth() {
        return salaryMonth;
    }

    public void setSalaryMonth(Date salaryMonth) {
        this.salaryMonth = salaryMonth;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getTeamId() {
        return teamId;
    }

    public void setTeamId(String teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public String getWorkType() {
        return workType;
    }

    public void setWorkType(String workType) {
        this.workType = workType;
    }
    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getBankCard() {
        return bankCard;
    }

    public void setBankCard(String bankCard) {
        this.bankCard = bankCard;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public Integer getWagesType() {
        return wagesType;
    }

    public void setWagesType(Integer wagesType) {
        this.wagesType = wagesType;
    }

    public Integer getSysCheckNum() {
        return sysCheckNum;
    }

    public void setSysCheckNum(Integer sysCheckNum) {
        this.sysCheckNum = sysCheckNum;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getActualCheckNum() {
        return actualCheckNum;
    }

    public void setActualCheckNum(BigDecimal actualCheckNum) {
        this.actualCheckNum = actualCheckNum;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }
    public BigDecimal getDeductMny() {
        return deductMny;
    }

    public void setDeductMny(BigDecimal deductMny) {
        this.deductMny = deductMny;
    }
    public String getDeductReason() {
        return deductReason;
    }

    public void setDeductReason(String deductReason) {
        this.deductReason = deductReason;
    }
    public BigDecimal getShouldSalaryMny() {
        return shouldSalaryMny;
    }

    public void setShouldSalaryMny(BigDecimal shouldSalaryMny) {
        this.shouldSalaryMny = shouldSalaryMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSource() {
        return source;
    }

    public void setSource(Integer source) {
        this.source = source;
    }

    public Date getAckTime() {
        return ackTime;
    }

    public void setAckTime(Date ackTime) {
        this.ackTime = ackTime;
    }

    public Integer getAckFlag() {
        return ackFlag;
    }

    public void setAckFlag(Integer ackFlag) {
        this.ackFlag = ackFlag;
    }
    public String getAckEquipment() {
        return ackEquipment;
    }

    public void setAckEquipment(String ackEquipment) {
        this.ackEquipment = ackEquipment;
    }
    
}

==> ejc-labor-api-3.0.0-20221130.033439-116-sources.jar: com/ejianc/business/labor/vo/SalarySlipVO.java <==
package com.ejianc.business.labor.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 工资条
 * 
 * @author generator
 * 
 */
public class SalarySlipVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 单据编码
    private Long salaryId; // 工人工资单主表id
    private Long salaryDetailId; // 工人工资单子表id
    @JsonFormat(pattern = "yyyy-MM", timezone = "GMT+8")
    private Date salaryMonth; // 工资月份
    private Long projectId; // 项目id
    private String projectName; // 项目名称
    private Long orgId; // 组织id
    private String orgName; // 组织名称
    private Long workerId; // 工人id
    private String workerName; // 工人
    private Long contractId; // 合同id
    private String contractName; // 合同名称
    private Long supplierId; // 加班计量方式
    private String supplierName; // 加班工作量
    private String idCard; // 身份证号码
    private String teamId; // 班组id
    private String teamName; // 班组名称
    private String workType; // 工种id
    private String workTypeName; // 工种名称
    private Integer sex; // 性別 1:男 2:女
    private String phone; // 手机号
    private String bankCard; // 银行卡号
    private String bankName; // 开户行
    private Integer wagesType; // 工资类型
    private Integer sysCheckNum; // 系统考勤天数
    private BigDecimal price; // 单价
    private BigDecimal actualCheckNum; // 实际考勤
    private BigDecimal mny; // 金额
    private BigDecimal overtimeMny; // 加班费
    private BigDecimal deductMny; // 扣款费用
    private String deductReason; // 扣款原因
    private BigDecimal shouldSalaryMny; // 应发工资:工作量*单价+加班工作量*单价
    private String memo; // 备注
    private Integer source; // 来源 1：花名册 2：自制
    private Integer ackFlag; // 确认状态：1：已确认:0：未确认
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private  Date  ackTime; // 确认时间
    private String logonPeople; // 登录人
    private Long facePhotoId; // 人脸照片id
    private String facePhoto; // 人脸照片地址
    private Long signPhotoId; // 签字照片id
    private String signPhoto; // 签字照片地址

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getSalaryId() {
        return salaryId;
    }

    public void setSalaryId(Long salaryId) {
        this.salaryId = salaryId;
    }
    public Long getSalaryDetailId() {
        return salaryDetailId;
    }

    public void setSalaryDetailId(Long salaryDetailId) {
        this.salaryDetailId = salaryDetailId;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getWorkerId() {
        return workerId;
    }

    public void setWorkerId(Long workerId) {
        this.workerId = workerId;
    }
    public String getWorkerName() {
        return workerName;
    }

    public void setWorkerName(String workerName) {
        this.workerName = workerName;
    }

    public Date getSalaryMonth() {
        return salaryMonth;
    }

    public void setSalaryMonth(Date salaryMonth) {
        this.salaryMonth = salaryMonth;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public String getContractName() {
        return contractName;
    }

    public void setContractName(String contractName) {
        this.contractName = contractName;
    }
    public Long getSupplierId() {
        return supplierId;
    }

    public void setSupplierId(Long supplierId) {
        this.supplierId = supplierId;
    }
    public String getSupplierName() {
        return supplierName;
    }

    public void setSupplierName(String supplierName) {
        this.supplierName = supplierName;
    }
    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
    public String getTeamId() {
        return teamId;
    }

    public void setTeamId(String teamId) {
        this.teamId = teamId;
    }
    public String getTeamName() {
        return teamName;
    }

    public void setTeamName(String teamName) {
        this.teamName = teamName;
    }
    public String getWorkType() {
        return workType;
    }

    public void setWorkType(String workType) {
        this.workType = workType;
    }
    public String getWorkTypeName() {
        return workTypeName;
    }

    public void setWorkTypeName(String workTypeName) {
        this.workTypeName = workTypeName;
    }
    public Integer getSex() {
        return sex;
    }

    public void setSex(Integer sex) {
        this.sex = sex;
    }
    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }
    public String getBankCard() {
        return bankCard;
    }

    public void setBankCard(String bankCard) {
        this.bankCard = bankCard;
    }
    public String getBankName() {
        return bankName;
    }

    public void setBankName(String bankName) {
        this.bankName = bankName;
    }
    public Integer getWagesType() {
        return wagesType;
    }

    public void setWagesType(Integer wagesType) {
        this.wagesType = wagesType;
    }

    public Integer getSysCheckNum() {
        return sysCheckNum;
    }

    public void setSysCheckNum(Integer sysCheckNum) {
        this.sysCheckNum = sysCheckNum;
    }
    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getActualCheckNum() {
        return actualCheckNum;
    }

    public void setActualCheckNum(BigDecimal actualCheckNum) {
        this.actualCheckNum = actualCheckNum;
    }

    public BigDecimal getMny() {
        return mny;
    }

    public void setMny(BigDecimal mny) {
        this.mny = mny;
    }
    public BigDecimal getOvertimeMny() {
        return overtimeMny;
    }

    public void setOvertimeMny(BigDecimal overtimeMny) {
        this.overtimeMny = overtimeMny;
    }
    public BigDecimal getDeductMny() {
        return deductMny;
    }

    public void setDeductMny(BigDecimal deductMny) {
        this.deductMny = deductMny;
    }
    public String getDeductReason() {
        return deductReason;
    }

    public void setDeductReason(String deductReason) {
        this.deductReason = deductReason;
    }
    public BigDecimal getShouldSalaryMny() {
        return shouldSalaryMny;
    }

    public void setShouldSalaryMny(BigDecimal shouldSalaryMny) {
        this.shouldSalaryMny = shouldSalaryMny;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getSource() {
        return source;
    }

    public void setSource(Integer source) {
        this.source = source;
    }

    public Date getAckTime() {
        return ackTime;
    }

    public void setAckTime(Date ackTime) {
        this.ackTime = ackTime;
    }

    public Integer getAckFlag() {
        return ackFlag;
    }

    public void setAckFlag(Integer ackFlag) {
        this.ackFlag = ackFlag;
    }

    public String getLogonPeople() {
        return logonPeople;
    }

    public void setLogonPeople(String logonPeople) {
        this.logonPeople = logonPeople;
    }

    public Long getFacePhotoId() {
        return facePhotoId;
    }

    public void setFacePhotoId(Long facePhotoId) {
        this.facePhotoId = facePhotoId;
    }

    public String getFacePhoto() {
        return facePhoto;
    }

    public void setFacePhoto(String facePhoto) {
        this.facePhoto = facePhoto;
    }

    public Long getSignPhotoId() {
        return signPhotoId;
    }

    public void setSignPhotoId(Long signPhotoId) {
        this.signPhotoId = signPhotoId;
    }

    public String getSignPhoto() {
        return signPhoto;
    }

    public void setSignPhoto(String signPhoto) {
        this.signPhoto = signPhoto;
    }
}
